############################################
# Purpose:
# This script can be used to remove all the contents of a Fortran code that can make it harder to parse.
# It will merge split lines, remove comments and empty lines.
#
# Inputs:
#
# "-s", "--input-source" path to a source-code folder which code will be cleaned.
#
#
############################################

from AutoRPE.UtilsRPE.Cleaner import remove_empty_lines, merge_lines, remove_comments
from AutoRPE.UtilsRPE.SourceManager import store_lines_into_file, load_file, expand_sources

if __name__ == "__main__":
    # Use OptionParser to parse command line arguments.
    from optparse import OptionParser
    parser = OptionParser()

    parser.add_option("-s", "--input-source", dest="input_source",
                      default=None, metavar="FILE")

    (options, args) = parser.parse_args()

    path = options.input_source

    if path is None:
        parser.print_help()
        exit(0)

    # Find all files inside the provided path
    files = expand_sources(path)

    # Loop over files
    for index, fn in enumerate(files):
        # Read file
        lines = load_file(fn)
        # Remove comments ignoring preprocessor statements
        for line_index, line in enumerate(lines):
            if line[0] == "#":
                continue
            lines[line_index] = remove_comments(line)
        # Remove empty lines
        lines = remove_empty_lines(lines)

        # Merge lines
        lines = merge_lines(lines)
        # Remove empty lines again
        lines = remove_empty_lines(lines)
        # Overwrite file with clean source
        store_lines_into_file(lines, fn)

